@@ -5,13 +5,11 @@ import logging
 
 import numpy as np
 import xarray as xr
+from nowcasting_dataset.consts import Array
+from nowcasting_dataset.time import make_random_time_vectors
 from pydantic import Field
 
-from nowcasting_dataset.consts import Array
-from nowcasting_dataloader.data_sources.datasource_output import (
-    DataSourceOutputML,
-)
-from nowcasting_dataset.time import make_random_time_vectors
+from nowcasting_dataloader.data_sources.datasource_output import DataSourceOutputML
 
 logger = logging.getLogger(__name__)
 
